"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.presetColors = exports.AnimatedGradient = void 0;
var _reactNative = require("react-native");
var _react = require("react");
var _reactNativeLinearGradient = _interopRequireDefault(require("react-native-linear-gradient"));
var _rgb2hex = _interopRequireDefault(require("rgb2hex"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
/* eslint-disable @typescript-eslint/no-use-before-define */

class LinearGradient extends _react.Component {
  render() {
    const {
      color0,
      color1,
      children,
      points,
      gradientStyle
    } = this.props;
    const gStart = points.start;
    const gEnd = points.end;
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeLinearGradient.default, {
      colors: [color0, color1].map(c => (0, _rgb2hex.default)(c).hex),
      start: gStart,
      end: gEnd,
      style: [!children && !gradientStyle && styles.fillHeight, gradientStyle],
      children: children
    });
  }
}
const AnimatedLinearGradient = _reactNative.Animated.createAnimatedComponent(LinearGradient);
const presetColors = exports.presetColors = {
  instagram: ['rgb(106, 57, 171)', 'rgb(151, 52, 160)', 'rgb(197, 57, 92)', 'rgb(231, 166, 73)', 'rgb(181, 70, 92)'],
  firefox: ['rgb(236, 190, 55)', 'rgb(215, 110, 51)', 'rgb(181, 63, 49)', 'rgb(192, 71, 45)'],
  sunrise: ['rgb(92, 160, 186)', 'rgb(106, 166, 186)', 'rgb(142, 191, 186)', 'rgb(172, 211, 186)', 'rgb(239, 235, 186)', 'rgb(212, 222, 206)', 'rgb(187, 216, 200)', 'rgb(152, 197, 190)', 'rgb(100, 173, 186)']
};
class AnimatedGradient extends _react.Component {
  static defaultProps = {
    customColors: presetColors.instagram,
    speed: 4000,
    points: {
      start: {
        x: 0,
        y: 0.4
      },
      end: {
        x: 1,
        y: 0.6
      }
    }
  };
  state = {
    color0: new _reactNative.Animated.Value(0),
    color1: new _reactNative.Animated.Value(0)
  };
  componentDidMount = () => {
    this.startAnimation();
  };
  startAnimation = () => {
    const {
      color0,
      color1
    } = this.state;
    const {
      customColors,
      speed
    } = this.props;
    [color0, color1].forEach(color => color.setValue(0));
    _reactNative.Animated.parallel([color0, color1].map(animatedColor => {
      return _reactNative.Animated.timing(animatedColor, {
        toValue: customColors.length,
        duration: customColors.length * speed,
        easing: _reactNative.Easing.linear,
        useNativeDriver: this.props.useNativeDriver || false
      });
    })).start(this.startAnimation);
  };
  render() {
    const {
      color0,
      color1
    } = this.state;
    const {
      customColors,
      children,
      points,
      style
    } = this.props;
    const preferColors = [];
    while (preferColors.length < 2) {
      preferColors.push(customColors.slice(preferColors.length).concat(customColors.slice(0, preferColors.length + 1)));
    }
    const interpolatedColors = [color0, color1].map((animatedColor, index) => {
      return animatedColor.interpolate({
        inputRange: Array.from({
          length: customColors.length + 1
        }, (v, k) => k),
        outputRange: preferColors[index]
      });
    });
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(AnimatedLinearGradient, {
      gradientStyle: style,
      points: points,
      color0: interpolatedColors[0],
      color1: interpolatedColors[1],
      children: children
    });
  }
}
exports.AnimatedGradient = AnimatedGradient;
const styles = _reactNative.StyleSheet.create({
  fillHeight: {
    flex: 1
  }
});

// export default AnimatedGradient;
//# sourceMappingURL=index.js.map